/*
 * DozierRandomCspC - A generator for random binary symmetric constraint satisfaction problems.
 * Part of the RandomCsp program.
 * Copyright (C) 1998 J.I. van Hemert
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 * Last revision: 01-Apr-1998
 *
 */


#ifndef _DozierRandomCspC_H
#define _DozierRandomCspC_H


#include "randomcsp.h"
#include <math.h>


/**
 * This class is capable of producing Random Binary Constraint Satisfaction
 * Problems. The usage is quite simple. After the creation of a object of this
 * class with all the correct parameters, the InitRandomGenerator function
 * should be used to set the seeds for the randomgenerator. This has to be done
 * at least once. Then a problem can be generated with the ProduceProblem
 * function and a filename can be produced with the ProduceFileName function
 *
 * @memo Random Constraint Satisfaction Problems
 *
 * @author J.I. van Hemert
 * @version 1.1
 *
 */

class DozierRandomCspC: 
	public RandomCspC
{
	public:

		
		DozierRandomCspC
		(
			NumberOfVariablesT const iNumberOfVariables,
			DomainSizeT const iDomainSize,
			bool const iRandomDomainSize,
			TightnessT const iTightness,
			ConnectivityT const iConnectivity
		): RandomCspC (iNumberOfVariables, iDomainSize, iRandomDomainSize, iTightness, iConnectivity) {};
		
		/**
		 * Produce a constraint satisfaction method using the method of Gerry
		 * Dozier, the method is copied from a Pascal version he send us.
		 *
		 * @memo Producing a Random CSP
		 *
		 * @return nothing.
		 * 
		 * @author J.I. van Hemert
		 * @version 1.1
		 *
		 */

		void const ProduceProblem ();

	protected:

	private:

}; // DozierRandomCspC


#endif

// eof gvdozier.h
