/*
 * RandomCsp - A empty class for random binary symmetric constraint satisfaction problems.
 * Part of the RandomCsp library.
 * Copyright (C) 1998 J.I. van Hemert
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * 
 * Last revision: 01-Apr-1998
 *
 */


#include "randomcsp.h"


//@{
/// A static randomgenerator
MLCG RandomCspC::RandomGenerator;
/// Seed one for the randomgenerator
int RandomCspC::Seed1;
/// Seed two for the randomgenerator
int RandomCspC::Seed2;
//@}



RandomCspC::RandomCspC
(
		NumberOfVariablesT const iNumberOfVariables,
		DomainSizeT const iDomainSize,
		bool const iRandomDomainSize,
		TightnessT const iTightness,
		ConnectivityT const iConnectivity
):
	CspC (iNumberOfVariables)
{

	RandomDomainSize = iRandomDomainSize;

	DomainSize = iDomainSize;
	if (DomainSize < 1)
		Error->Give ("Domainsize should be larger than 0.", Error->error);

	Tightness = iTightness;
	if ((Tightness < 0) || (Tightness > 1))
		Error->Give ("Tightness should be between 0 and 1.", Error->error);

	Connectivity = iConnectivity;
	if ((Connectivity < 0) || (Connectivity > 1))
		Error->Give ("Connectivity should be between 0 and 1.", Error->error);

} // RandomCspC::RandomCspC



RandomCspC::~RandomCspC ()
{
} // RandomCspC::~RandomCspC



void const RandomCspC::InitRandomGenerator
(
	int const iRandomSeed1,
	int const iRandomSeed2
)
{
	Seed1 = iRandomSeed1;
	Seed2 = iRandomSeed2;

	RandomGenerator.seed1(Seed1);
	RandomGenerator.seed2(Seed2);
	
} // RandomCspC::InitRandomGenerator



void const RandomCspC::ProduceProblem ()
{
} // RandomCspC::ProduceProblem



void RandomCspC::ProduceFileName
(
	char * FileName
)
{
	char * Tmp;

	Tmp = new char [70];

#if defined (Linux)
	snprintf (Tmp, 30, "v=%i-d=%i", GetNumberOfVariables (), DomainSize);
#else
	sprintf (Tmp, "v=%i-d=%i", GetNumberOfVariables (), DomainSize);
#endif
	strcpy (FileName, Tmp);

	if (RandomDomainSize)
		strcat (FileName, "-r");
	else
		strcat (FileName, "-c");

#if defined (Linux)
	snprintf (Tmp, 60, "-t=%.10g-c=%.10g-s1=%i-s2=%i.csp", Tightness, Connectivity, Seed1, Seed2);
#else
	sprintf (Tmp, "-t=%.10g-c=%.10g-s1=%i-s2=%i.csp", Tightness, Connectivity, Seed1, Seed2);
#endif

	strcat (FileName, Tmp);

	delete Tmp;
	
} // RandomCspC::ProduceFileName



// eof pprosser.cc
